@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * link_dialog.c - dialog for inserting a link
  *
- * Copyright (C) 2005-2015 Xiphos Developer Team
+ * Copyright (C) 2005-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -148,7 +148,7 @@ void editor_link_dialog(EDITOR *e)
 	gbuilder_file =
 	    gui_general_user_file("editor_link_dialog.xml", FALSE);
 
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	builder = gtk_builder_new_from_file(gbuilder_file);
 #else
 	builder = gtk_builder_new();
