@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * dictlex.c - gui for commentary modules
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -279,7 +279,7 @@ static void menu_position_under(GtkMenu *menu,
 	GtkAllocation allocation;
 
 	g_return_if_fail(GTK_IS_BUTTON(user_data));
-#if defined(HAVE_GTK_220) || defined(USE_GTK_3)
+#if GTK_CHECK_VERSION(2, 20, 0)
 	g_return_if_fail(gtk_widget_get_window(user_data));
 #else
 	g_return_if_fail(GTK_WIDGET_NO_WINDOW(user_data));
@@ -358,7 +358,9 @@ GtkWidget *gui_create_dictionary_pane(void)
 	GtkWidget *image2;
 	GtkWidget *arrow1;
 	GtkWidget *dict_drop_down;
+#ifndef USE_WEBKIT2
 	GtkWidget *scrolledwindow;
+#endif
 
 	UI_VBOX(box_dict, FALSE, 0);
 	gtk_widget_show(box_dict);
@@ -378,7 +380,7 @@ GtkWidget *gui_create_dictionary_pane(void)
 	gtk_widget_show(dict_drop_down);
 	gtk_box_pack_start(GTK_BOX(hbox2), dict_drop_down, FALSE, TRUE, 0);
 
-#ifdef HAVE_GTK_314
+#if GTK_CHECK_VERSION(3, 14, 0)
 	arrow1 =
 	    gtk_image_new_from_icon_name("open-menu-symbolic",
 					 GTK_ICON_SIZE_BUTTON);
@@ -394,7 +396,7 @@ GtkWidget *gui_create_dictionary_pane(void)
 	gtk_button_set_relief(GTK_BUTTON(button10), GTK_RELIEF_NONE);
 
 	image1 =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_image_new_from_icon_name("go-up-symbolic",
 					 GTK_ICON_SIZE_BUTTON);
 #else
@@ -410,7 +412,7 @@ GtkWidget *gui_create_dictionary_pane(void)
 	gtk_button_set_relief(GTK_BUTTON(button11), GTK_RELIEF_NONE);
 
 	image2 =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_image_new_from_icon_name("go-down-symbolic",
 					 GTK_ICON_SIZE_BUTTON);
 #else
@@ -420,6 +422,7 @@ GtkWidget *gui_create_dictionary_pane(void)
 	gtk_widget_show(image2);
 	gtk_container_add(GTK_CONTAINER(button11), image2);
 
+#ifndef USE_WEBKIT2
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
 	gtk_box_pack_start(GTK_BOX(box_dict), scrolledwindow, TRUE, TRUE,
@@ -428,12 +431,17 @@ GtkWidget *gui_create_dictionary_pane(void)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolledwindow,
 					    settings.shadow_type);
+#endif
 
 	widgets.html_dict =
 	    GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, DICTIONARY_TYPE));
 	gtk_widget_show(widgets.html_dict);
+#ifdef USE_WEBKIT2
+	gtk_box_pack_start(GTK_BOX(box_dict), widgets.html_dict, TRUE, TRUE, 0);
+#else
 	gtk_container_add(GTK_CONTAINER(scrolledwindow),
 			  widgets.html_dict);
+#endif
 	g_signal_connect((gpointer)widgets.html_dict,
 			 "popupmenu_requested",
 			 G_CALLBACK(_popupmenu_requested_cb), NULL);
