@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * font_dialog.c - dialog to set module font
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,18 +64,16 @@ static MOD_FONT *mf;
 static gchar *get_html_font_name(gchar *fontname)
 {
 	gchar buf[80];
-	gint len, i = 0;
+	gint idx, i = 0;
 
-	len = strlen(fontname);
-	for (i = 0; (i < 79 && i < len - 3); i++) {
-		if (!isdigit(fontname[i])) {
-			buf[i] = fontname[i];
-			buf[i + 1] = '\0';
-		} else
-			break;
-	}
+	/* strip trailing size digits from picker-chosen name. */
+	idx = strlen(fontname) - 1;
+	while ((idx > 0) && isdigit(fontname[idx]))
+		fontname[idx--] = '\0';
+	if (fontname[idx] = ' ')
+		fontname[idx] = '\0';
 
-	return g_strdup(buf);
+	return g_strdup(fontname);
 }
 
 /******************************************************************************
@@ -313,7 +311,7 @@ static GtkWidget *create_dialog_mod_font()
 	gtk_box_pack_start(GTK_BOX(vbox56), hbox67, TRUE, TRUE, 0);
 
 	pixmap6 =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_image_new_from_icon_name("gtk-select-font",
 					 GTK_ICON_SIZE_DND);
 #else
@@ -402,7 +400,7 @@ static GtkWidget *create_dialog_mod_font()
 			   FALSE, 0);
 
 	dialog_action_area21 =
-#ifdef HAVE_GTK_312
+#if GTK_CHECK_VERSION(3, 12, 0)
 	    gtk_dialog_get_content_area(GTK_DIALOG(dialog_mod_font));
 #else
 	    gtk_dialog_get_action_area(GTK_DIALOG(dialog_mod_font));
@@ -424,7 +422,7 @@ static GtkWidget *create_dialog_mod_font()
 				  GTK_BUTTONBOX_EDGE);
 
 	button_cancel =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_button_new_with_label("Cancel");
 #else
 	    gtk_button_new_from_stock(GTK_STOCK_CANCEL);
@@ -433,7 +431,7 @@ static GtkWidget *create_dialog_mod_font()
 	gtk_container_add(GTK_CONTAINER(hbuttonbox1), button_cancel);
 	gtk_widget_set_can_default(button_cancel, 1);
 	button_ok =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_button_new_with_label("OK");
 #else
 	    gtk_button_new_from_stock(GTK_STOCK_OK);
