@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * main_menu.c - creation of and call backs for xiphos main menu
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -142,7 +142,29 @@ on_help_contents_activate(GtkMenuItem *menuitem, gpointer user_data)
 G_MODULE_EXPORT void
 on_mailing_list_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
-	xiphos_open_default("https://lists.sourceforge.net/lists/listinfo/gnomesword-users/");
+	xiphos_open_default("http://www.crosswire.org/mailman/listinfo/xiphos-users/");
+}
+
+/******************************************************************************
+ * Name
+ *  on_view_releases_activate
+ *
+ * Synopsis
+ *   #include "gui/main_menu.h"
+ *
+ *   void on_view_releases_activate(GtkMenuItem * menuitem,
+ *				    gpointer user_data)
+ *
+ * Description
+ *   open web browser to GitHub releases page.
+ *
+ * Return value
+ *   void
+ */
+G_MODULE_EXPORT void
+on_view_releases_activate(GtkMenuItem *menuitem, gpointer user_data)
+{
+	xiphos_open_default("https://github.com/crosswire/xiphos/releases/");
 }
 
 /******************************************************************************
@@ -208,7 +230,7 @@ on_live_chat_activate(GtkMenuItem *menuitem, gpointer user_data)
  *						gpointer user_data)
  *
  * Description
- *   open web browser to sourceforge bug tracker
+ *   open web browser to github bug tracker
  *
  * Return value
  *   void
@@ -600,7 +622,7 @@ on_save_session_activate(GtkMenuItem *menuitem, gpointer user_data)
 	dialog = gtk_file_chooser_dialog_new("Save Session",
 					     NULL,
 					     GTK_FILE_CHOOSER_ACTION_SAVE,
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 					     "_Cancel",
 					     GTK_RESPONSE_CANCEL, "_Save",
 					     GTK_RESPONSE_ACCEPT,
@@ -716,7 +738,7 @@ on_open_session_activate(GtkMenuItem *menuitem, gpointer user_data)
 	dialog = gtk_file_chooser_dialog_new("Open Session",
 					     NULL,
 					     GTK_FILE_CHOOSER_ACTION_OPEN,
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 					     "_Cancel",
 					     GTK_RESPONSE_CANCEL, "_Open",
 					     GTK_RESPONSE_ACCEPT,
