@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * menu_popup.c - main window panes and dialogs popup menus
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1854,7 +1854,7 @@ static GtkWidget *_create_popup_menu(XiphosHtml *html, const gchar *mod_name,
 		return NULL;
 
 #ifdef USE_GTKBUILDER
-#ifdef HAVE_GTK_314
+#if GTK_CHECK_VERSION(3, 14, 0)
 	glade_file =
 	    gui_general_user_file("xi-menus-popup.gtkbuilder", FALSE);
 #else
