@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * parallel_dialog.c - dialog for detached parallel
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -340,7 +340,9 @@ static GtkWidget *create_parallel_dialog(void)
 	GtkWidget *dialog_action_area25;
 	GtkWidget *hbuttonbox4;
 	GtkWidget *btnDockInt;
+#ifndef USE_WEBKIT2
 	GtkWidget *scrolled_window;
+#endif
 	gchar title[256];
 
 	sprintf(title, "%s - %s", settings.program_title, _("Parallel"));
@@ -399,6 +401,7 @@ static GtkWidget *create_parallel_dialog(void)
 	}
 #endif /* 0 */
 
+#ifndef USE_WEBKIT2
 	scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolled_window);
 	gtk_box_pack_start(GTK_BOX(vboxInt), scrolled_window, TRUE, TRUE,
@@ -409,20 +412,24 @@ static GtkWidget *create_parallel_dialog(void)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolled_window,
 					    settings.shadow_type);
+#endif
 
 	widgets.html_parallel_dialog =
 	    GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, PARALLEL_TYPE));
 	gtk_widget_show(widgets.html_parallel_dialog);
-
+#ifdef USE_WEBKIT2
+	gtk_box_pack_start(GTK_BOX(vboxInt), widgets.html_parallel_dialog, TRUE, TRUE, 0);
+#else
 	gtk_container_add(GTK_CONTAINER(scrolled_window),
 			  widgets.html_parallel_dialog);
+#endif
 
 	g_signal_connect((gpointer)widgets.html_parallel_dialog,
 			 "popupmenu_requested",
 			 G_CALLBACK(_popupmenu_requested_cb), NULL);
 
 	dialog_action_area25 =
-#ifdef HAVE_GTK_312
+#if GTK_CHECK_VERSION(3, 12, 0)
 	    gtk_dialog_get_content_area(GTK_DIALOG(dialog_parallel));
 #else
 	    gtk_dialog_get_action_area(GTK_DIALOG(dialog_parallel));
@@ -439,7 +446,7 @@ static GtkWidget *create_parallel_dialog(void)
 #endif
 	gtk_widget_show(hbuttonbox4);
 
-#ifdef HAVE_GTK_312
+#if GTK_CHECK_VERSION(3, 12, 0)
 	gtk_box_pack_start(GTK_BOX(dialog_action_area25), hbuttonbox4,
 			   FALSE, TRUE, 3);
 #else
@@ -450,7 +457,7 @@ static GtkWidget *create_parallel_dialog(void)
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox4),
 				  GTK_BUTTONBOX_END);
 	btnDockInt =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_button_new_from_icon_name("window-close",
 					  GTK_ICON_SIZE_BUTTON);
 #else
