@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * preferences_dialog.c - get user preferences
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -112,6 +112,7 @@ struct _preferences_check_buttons
 	GtkWidget *show_splash_screen;
 	GtkWidget *prayerlist;
 	GtkWidget *statusbar;
+	GtkWidget *alternation;
 
 	GtkWidget *show_in_viewer;
 	GtkWidget *show_in_dictionary;
@@ -248,7 +249,7 @@ static gboolean on_prefs_configure_event(GtkWidget *widget,
  * Return value
  *   gint
  */
-#ifndef HAVE_GTK_34
+#if !GTK_CHECK_VERSION(3, 4, 0)
 static gint string_is_color(gchar *color)
 {
 	gint i;
@@ -266,8 +267,12 @@ static gint string_is_color(gchar *color)
 		return 0;
 	}
 	for (i = 1; i < 7; i++) {
-		if ((color[i] > 102) || (color[i] < 48) || ((color[i] > 57) && (color[i] < 65)) || ((color[i] > 70) && (color[i] < 97))) {
-			XI_warning(("string_is_color, %d in %s is not from a color, it is %d\n", i, color, color[i]));
+		if ((color[i] > 102) || 
+		    (color[i] < 48) || 
+		    ((color[i] > 57) && (color[i] < 65)) || 
+		    ((color[i] > 70) && (color[i] < 97))) {
+			XI_warning(("string_is_color, %d in %s is not from a color, it is %d\n",
+				    i, color, color[i]));
 			return 0;
 		}
 	}
@@ -276,7 +281,7 @@ static gint string_is_color(gchar *color)
 }
 #endif
 
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 static gchar *gdkrgba_to_hex(GdkRGBA *color)
 {
 	gchar *tmpstr;
@@ -417,7 +422,7 @@ void
 on_colorbutton1_color_set(GtkColorButton *colorbutton, gpointer user_data)
 {
 	gchar *buf = NULL;
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	GdkRGBA color;
 	gtk_color_chooser_get_rgba((GtkColorChooser *)colorbutton,
 				   &color);
@@ -454,7 +459,7 @@ void
 on_colorbutton2_color_set(GtkColorButton *colorbutton, gpointer user_data)
 {
 	gchar *buf2 = NULL;
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	GdkRGBA color;
 
 	gtk_color_chooser_get_rgba((GtkColorChooser *)colorbutton,
@@ -492,7 +497,7 @@ void
 on_colorbutton3_color_set(GtkColorButton *colorbutton, gpointer user_data)
 {
 	gchar *buf2 = NULL;
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	GdkRGBA color;
 
 	gtk_color_chooser_get_rgba((GtkColorChooser *)colorbutton,
@@ -531,7 +536,7 @@ void
 on_colorbutton4_color_set(GtkColorButton *colorbutton, gpointer user_data)
 {
 	gchar *buf2 = NULL;
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	GdkRGBA color;
 
 	gtk_color_chooser_get_rgba((GtkColorChooser *)colorbutton,
@@ -570,7 +575,7 @@ void
 on_colorbutton5_color_set(GtkColorButton *colorbutton, gpointer user_data)
 {
 	gchar *buf2 = NULL;
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	GdkRGBA color;
 
 	gtk_color_chooser_get_rgba((GtkColorChooser *)colorbutton,
@@ -608,7 +613,7 @@ void
 on_colorbutton6_color_set(GtkColorButton *colorbutton, gpointer user_data)
 {
 	gchar *buf2 = NULL;
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	GdkRGBA color;
 
 	gtk_color_chooser_get_rgba((GtkColorChooser *)colorbutton,
@@ -647,7 +652,7 @@ void
 on_colorbutton7_color_set(GtkColorButton *colorbutton, gpointer user_data)
 {
 	gchar *buf2 = NULL;
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	GdkRGBA color;
 
 	gtk_color_chooser_get_rgba((GtkColorChooser *)colorbutton,
@@ -852,7 +857,7 @@ gchar *on_biblesync_obtain_passphrase()
 {
 	gchar *retval;
 	GS_DIALOG *info = gui_new_dialog();
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	info->stock_icon = g_strdup("dialog-warning");
 #else
 	info->stock_icon = g_strdup(GTK_STOCK_DIALOG_WARNING);
@@ -935,27 +940,21 @@ on_radiobutton_biblesync_mode(GtkToggleButton *togglebutton,
 					      "again to see why."));
 			settings.bs_mode = new_mode;
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_button.bs_mode_off),
-						     (settings.bs_mode ==
-						      0));
+						     (settings.bs_mode == 0));
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_button.bs_mode_personal),
-						     (settings.bs_mode ==
-						      1));
+						     (settings.bs_mode == 1));
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_button.bs_mode_speaker),
-						     (settings.bs_mode ==
-						      2));
+						     (settings.bs_mode == 2));
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_button.bs_mode_audience),
-						     (settings.bs_mode ==
-						      3));
+						     (settings.bs_mode == 3));
 		}
 
 		if (biblesync_personal()) {
-			gtk_widget_set_sensitive(check_button.bs_privacy,
-						 TRUE);
+			gtk_widget_set_sensitive(check_button.bs_privacy, TRUE);
 			on_checkbutton_biblesync_toggled(GTK_TOGGLE_BUTTON(check_button.bs_privacy),
 							 &settings.bs_privacy);
 		} else {
-			gtk_widget_set_sensitive(check_button.bs_privacy,
-						 FALSE);
+			gtk_widget_set_sensitive(check_button.bs_privacy, FALSE);
 		}
 	}
 }
@@ -1448,6 +1447,35 @@ on_checkbutton_statusbar_toggled(GtkToggleButton *togglebutton, gpointer user_da
 		gtk_widget_hide(widgets.appbar);
 }
 
+/******************************************************************************
+ * Name
+ *   on_checkbutton_alternation_toggled
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *   void on_checkbutton_alternation_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+ *
+ * Description
+ *
+ * Return value
+ *   void
+ */
+
+void
+on_checkbutton_alternation_toggled(GtkToggleButton *togglebutton, gpointer user_data)
+{
+	xml_set_value("Xiphos", "misc", "alternation",
+		      (gtk_toggle_button_get_active(togglebutton) ? "1" : "0"));
+	settings.alternation = gtk_toggle_button_get_active(togglebutton);
+
+	main_update_parallel_page();	/* 1 verse */
+	if (settings.dockedInt) {	/* whole chapter */
+		main_update_parallel_page();
+	} else {
+		main_update_parallel_page_detached();
+	}
+}
+
 /******************************************************************************
  * Name
  *   on_folder_changed
@@ -2051,7 +2079,7 @@ static GtkTreeModel *create_model(void)
 
 void setup_color_pickers(void)
 {
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	GdkRGBA rgba;
 	if (gdk_rgba_parse(&rgba, settings.bible_bg_color))
 		gtk_color_chooser_set_rgba((GtkColorChooser *)
@@ -2172,6 +2200,8 @@ static void setup_check_buttons(void)
 				     settings.prayerlist);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button.statusbar),
 				     settings.statusbar);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button.alternation),
+				     settings.alternation);
 
 	/* v-- BibleSync --v */
 	/* toggles */
@@ -2247,6 +2277,9 @@ static void setup_check_buttons(void)
 	g_signal_connect(check_button.statusbar, "toggled",
 			 G_CALLBACK(on_checkbutton_statusbar_toggled),
 			 NULL);
+	g_signal_connect(check_button.alternation, "toggled",
+			 G_CALLBACK(on_checkbutton_alternation_toggled),
+			 NULL);
 
 	/* v-- BibleSync --v */
 	g_signal_connect(check_button.bs_debug, "toggled",
@@ -2721,7 +2754,7 @@ void ps_button_clear(GtkButton *button, gpointer user_data)
 				_("Clear List?"),
 				_("Are you sure you want to clear the module list?"));
 
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	if (gui_yes_no_dialog(str, "dialog-warning")) {
 #else
 	if (gui_yes_no_dialog(str, GTK_STOCK_DIALOG_WARNING)) {
@@ -2773,7 +2806,7 @@ void ps_button_cut(GtkButton *button, gpointer user_data)
 			      _("Remove Module?"),
 			      _("Are you sure you want to remove the selected module?"));
 
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	if (gui_yes_no_dialog(str, "dialog-warning")) {
 #else
 	if (gui_yes_no_dialog(str, GTK_STOCK_DIALOG_WARNING)) {
@@ -2897,82 +2930,57 @@ static void create_preferences_dialog(void)
 	/* color pickers */
 	color_picker.text_background = UI_GET_ITEM(gxml, "colorbutton1");
 	color_picker.text = UI_GET_ITEM(gxml, "colorbutton2");
-	color_picker.text_current_verse =
-	    UI_GET_ITEM(gxml, "colorbutton3");
+	color_picker.text_current_verse = UI_GET_ITEM(gxml, "colorbutton3");
 	color_picker.verse_numbers = UI_GET_ITEM(gxml, "colorbutton4");
-	color_picker.href_links = UI_GET_ITEM(gxml, "colorbutton5");
-	color_picker.highlight_fg = UI_GET_ITEM(gxml, "colorbutton6");
-	color_picker.highlight_bg = UI_GET_ITEM(gxml, "colorbutton7");
+	color_picker.href_links    = UI_GET_ITEM(gxml, "colorbutton5");
+	color_picker.highlight_fg  = UI_GET_ITEM(gxml, "colorbutton6");
+	color_picker.highlight_bg  = UI_GET_ITEM(gxml, "colorbutton7");
 
 	color_picker.invert_normal = UI_GET_ITEM(gxml, "invert_normal");
 	color_picker.invert_highlight =
 	    UI_GET_ITEM(gxml, "invert_highlight");
 
-	check_button.use_linked_tabs = UI_GET_ITEM(gxml, "checkbutton10");
-	check_button.readaloud = UI_GET_ITEM(gxml, "checkbutton11");
-	check_button.show_verse_num = UI_GET_ITEM(gxml, "checkbutton12");
-	check_button.use_default_dictionary =
-	    UI_GET_ITEM(gxml, "checkbutton6");
-	check_button.show_devotion = UI_GET_ITEM(gxml, "checkbutton7");
-	check_button.show_splash_screen =
-	    UI_GET_ITEM(gxml, "checkbutton8");
-	check_button.use_chapter_scroll =
-	    UI_GET_ITEM(gxml, "checkbutton_scroll");
+	check_button.use_linked_tabs        = UI_GET_ITEM(gxml, "checkbutton10");
+	check_button.readaloud              = UI_GET_ITEM(gxml, "checkbutton11");
+	check_button.show_verse_num         = UI_GET_ITEM(gxml, "checkbutton12");
+	check_button.use_default_dictionary = UI_GET_ITEM(gxml, "checkbutton6");
+	check_button.show_devotion          = UI_GET_ITEM(gxml, "checkbutton7");
+	check_button.show_splash_screen     = UI_GET_ITEM(gxml, "checkbutton8");
+	check_button.use_chapter_scroll     = UI_GET_ITEM(gxml, "checkbutton_scroll");
 
-	check_button.use_imageresize =
-	    UI_GET_ITEM(gxml, "checkbutton_imageresize");
+	check_button.use_imageresize = UI_GET_ITEM(gxml, "checkbutton_imageresize");
 #ifdef WIN32
 	/* webkit image hackery requires resize always be enabled. */
 	gtk_widget_hide(check_button.use_imageresize);
 #endif
-	check_button.use_verse_num_bold =
-	    UI_GET_ITEM(gxml, "checkbutton_verse_num_bold");
-	check_button.use_verse_num_bracket =
-	    UI_GET_ITEM(gxml, "checkbutton_verse_num_bracket");
-	check_button.use_verse_num_superscript =
-	    UI_GET_ITEM(gxml, "checkbutton_verse_num_superscript");
-	check_button.versehighlight =
-	    UI_GET_ITEM(gxml, "checkbutton_versehighlight");
-	check_button.annotate_highlight =
-	    UI_GET_ITEM(gxml, "checkbutton_annotate_highlight");
-	check_button.xrefs_in_verse_list =
-	    UI_GET_ITEM(gxml, "checkbutton_xrefs_in_verse_list");
-	check_button.prayerlist =
-	    UI_GET_ITEM(gxml, "checkbutton_prayerlist");
-	check_button.statusbar = UI_GET_ITEM(gxml, "checkbutton_statusbar");
+	check_button.use_verse_num_bold        = UI_GET_ITEM(gxml, "checkbutton_verse_num_bold");
+	check_button.use_verse_num_bracket     = UI_GET_ITEM(gxml, "checkbutton_verse_num_bracket");
+	check_button.use_verse_num_superscript = UI_GET_ITEM(gxml, "checkbutton_verse_num_superscript");
+	check_button.versehighlight      = UI_GET_ITEM(gxml, "checkbutton_versehighlight");
+	check_button.annotate_highlight  = UI_GET_ITEM(gxml, "checkbutton_annotate_highlight");
+	check_button.xrefs_in_verse_list = UI_GET_ITEM(gxml, "checkbutton_xrefs_in_verse_list");
+	check_button.prayerlist          = UI_GET_ITEM(gxml, "checkbutton_prayerlist");
+	check_button.statusbar           = UI_GET_ITEM(gxml, "checkbutton_statusbar");
+	check_button.alternation         = UI_GET_ITEM(gxml, "checkbutton_alternation");
 
 	/* v-- BibleSync --v */
-	check_button.bs_debug =
-	    UI_GET_ITEM(gxml, "checkbutton_BSP_nav_debug");
-	check_button.bs_presence =
-	    UI_GET_ITEM(gxml, "checkbutton_BSP_presence");
-	check_button.bs_mismatch =
-	    UI_GET_ITEM(gxml, "checkbutton_BSP_mismatch");
-	check_button.bs_group_tab =
-	    UI_GET_ITEM(gxml, "checkbutton_BSP_group_tab");
-	check_button.bs_privacy =
-	    UI_GET_ITEM(gxml, "checkbutton_BSP_privacy");
+	check_button.bs_debug     = UI_GET_ITEM(gxml, "checkbutton_BSP_nav_debug");
+	check_button.bs_presence  = UI_GET_ITEM(gxml, "checkbutton_BSP_presence");
+	check_button.bs_mismatch  = UI_GET_ITEM(gxml, "checkbutton_BSP_mismatch");
+	check_button.bs_group_tab = UI_GET_ITEM(gxml, "checkbutton_BSP_group_tab");
+	check_button.bs_privacy   = UI_GET_ITEM(gxml, "checkbutton_BSP_privacy");
 
-	radio_button.bs_mode_off =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_off");
-	radio_button.bs_mode_personal =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_personal");
-	radio_button.bs_mode_speaker =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_speaker");
-	radio_button.bs_mode_audience =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_audience");
+	radio_button.bs_mode_off      = UI_GET_ITEM(gxml, "radiobutton_BSP_off");
+	radio_button.bs_mode_personal = UI_GET_ITEM(gxml, "radiobutton_BSP_personal");
+	radio_button.bs_mode_speaker  = UI_GET_ITEM(gxml, "radiobutton_BSP_speaker");
+	radio_button.bs_mode_audience = UI_GET_ITEM(gxml, "radiobutton_BSP_audience");
 
-	radio_button.bs_nav_direct =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_nav_direct");
-	radio_button.bs_nav_verselist =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_nav_verselist");
+	radio_button.bs_nav_direct    = UI_GET_ITEM(gxml, "radiobutton_BSP_nav_direct");
+	radio_button.bs_nav_verselist = UI_GET_ITEM(gxml, "radiobutton_BSP_nav_verselist");
 
-	radio_button.bs_listen_some =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_listen_some");
-	radio_button.bs_listen_all =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_listen_all");
-	radio_button.bs_listen_none =
-	    UI_GET_ITEM(gxml, "radiobutton_BSP_listen_none");
+	radio_button.bs_listen_some = UI_GET_ITEM(gxml, "radiobutton_BSP_listen_some");
+	radio_button.bs_listen_all  = UI_GET_ITEM(gxml, "radiobutton_BSP_listen_all");
+	radio_button.bs_listen_none = UI_GET_ITEM(gxml, "radiobutton_BSP_listen_none");
 
 	speaker_window = UI_GET_ITEM(gxml, "speakerwindow");
 	biblesync_update_speaker();
