@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_dialog.c - gui for searching Sword modules
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -303,7 +303,7 @@ void on_button_begin_search(GtkButton *button, gpointer user_data)
 {
 	if (search_active) {
 		terminate_search = TRUE;
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 		gtk_button_set_image((GtkButton *)remember_search,
 				     gtk_image_new_from_icon_name("edit-find", GTK_ICON_SIZE_BUTTON));
 #else
@@ -315,7 +315,7 @@ void on_button_begin_search(GtkButton *button, gpointer user_data)
 #endif
 		sync_windows();
 	} else {
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 		gtk_button_set_image((GtkButton *)remember_search,
 				     gtk_image_new_from_icon_name("process-stop",
 								  GTK_ICON_SIZE_BUTTON));
@@ -329,7 +329,7 @@ void on_button_begin_search(GtkButton *button, gpointer user_data)
 		// do the search
 		main_do_dialog_search();
 
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 		gtk_button_set_image((GtkButton *)remember_search,
 				     gtk_image_new_from_icon_name("edit-find", GTK_ICON_SIZE_BUTTON));
 #else
@@ -519,7 +519,7 @@ void clear_modules(GtkButton *button, gpointer user_data)
 			      _("Clear List?"),
 			      _("Are you sure you want to clear the module list?"));
 
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	if (gui_yes_no_dialog(str, "dialog-warning")) {
 #else
 	if (gui_yes_no_dialog(str, GTK_STOCK_DIALOG_WARNING)) {
@@ -716,7 +716,7 @@ void delete_list(GtkButton *button, gpointer user_data)
 			      _("Are you sure you want to delete:"),
 			      name_string);
 
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	if (!gui_yes_no_dialog(str, "dialog-warning")) {
 		g_free(name_string);
 		g_free(str);
@@ -815,10 +815,13 @@ void mod_list_toggled(GtkToggleButton *togglebutton, gpointer user_data)
 
 void optimized_toggled(GtkToggleButton *togglebutton, gpointer user_data)
 {
-	if (gtk_toggle_button_get_active(togglebutton))
+	if (gtk_toggle_button_get_active(togglebutton)) {
 		gtk_widget_show(search1.button_intro_lucene);
-	else
+		gtk_widget_set_sensitive(search1.cb_case_sensitive, FALSE);
+	} else {
 		gtk_widget_hide(search1.button_intro_lucene);
+		gtk_widget_set_sensitive(search1.cb_case_sensitive, TRUE);
+	}
 }
 
 /******************************************************************************
@@ -1235,7 +1238,7 @@ GtkWidget *create_results_menu_advsearch(void)
 	gchar *glade_file;
 #ifdef USE_GTKBUILDER
 	GtkBuilder *gxml;
-#ifdef HAVE_GTK_314
+#if GTK_CHECK_VERSION(3, 14, 0)
 	glade_file =
 	    gui_general_user_file("xi-menus-popup.gtkbuilder", FALSE);
 #else
@@ -1643,6 +1646,7 @@ on_toolbutton12_clicked(GtkToolButton *toolbutton, gpointer user_data)
 /* add html widgets */
 static void _add_html_widget(GtkWidget *vbox)
 {
+#ifndef USE_WEBKIT2
 	GtkWidget *scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
 	gtk_box_pack_start(GTK_BOX(vbox), scrolledwindow, TRUE, TRUE, 0);
@@ -1652,13 +1656,19 @@ static void _add_html_widget(GtkWidget *vbox)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolledwindow,
 					    settings.shadow_type);
+#endif
+
 	search1.preview_html =
 	    GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, DIALOG_SEARCH_PREVIEW_TYPE));
+	gtk_widget_show(search1.preview_html);
+#ifdef USE_WEBKIT2
+	gtk_box_pack_start(GTK_BOX(vbox), search1.preview_html, TRUE, TRUE, 0);
+#else
 	gtk_container_add(GTK_CONTAINER(scrolledwindow),
 			  search1.preview_html);
 	gtk_box_pack_start(GTK_BOX(scrolledwindow), search1.preview_html,
 			   TRUE, TRUE, 0);
-	gtk_widget_show(search1.preview_html);
+#endif
 }
 
 /******************************************************************************
@@ -1949,6 +1959,9 @@ static void _create_search_dialog(void)
 	settings.display_advsearch = 1;
 	xml_set_value("Xiphos", "layout", "advsearchopen", "1");
 
+	/* disable match case initially */
+	gtk_widget_set_sensitive(search1.cb_case_sensitive, FALSE);
+
 	/*
 	 * (from xiphos.c)
 	 * a little paranoia:
