@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sidebar.c - create and maintain the new sidebar bar
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -405,10 +405,12 @@ void gui_set_sidebar_program_start(void)
 	/* set width of bible pane */
 	//gtk_paned_set_position(GTK_PANED(widgets.hpaned), settings.biblepane_width);
 
+#if 0
 	if (!settings.docked) {
 		settings.docked = TRUE;
 		//gui_attach_detach_shortcutbar();
 	}
+#endif
 }
 
 /******************************************************************************
@@ -845,14 +847,15 @@ on_open_in_dialog_activate(GtkMenuItem *menuitem, gpointer user_data)
 						  "0", BOOK_EDITOR);
 		} else {
 			if (mod_type == PERCOM_TYPE)
-				main_dialogs_open(buf_module, (gchar *)
-							      settings.currentverse);
+				main_dialogs_open(buf_module,
+						  (gchar *) settings.currentverse,
+						  FALSE);
 			else
-				main_dialogs_open(buf_module, NULL);
+				main_dialogs_open(buf_module, NULL, FALSE);
 		}
 		g_free(dialog_text);
 	} else
-		main_dialogs_open(buf_module, NULL);
+		main_dialogs_open(buf_module, NULL, FALSE);
 
 	g_free(buf_module);
 	buf_module = NULL;
@@ -925,7 +928,7 @@ on_populate_verse_list_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	GS_DIALOG *info = gui_new_dialog();
 
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	info->stock_icon = g_strdup("dialog-warning");
 #else
 	info->stock_icon = g_strdup(GTK_STOCK_DIALOG_WARNING);
@@ -1018,7 +1021,7 @@ GtkWidget *create_results_menu(void)
 	gchar *glade_file;
 #ifdef USE_GTKBUILDER
 	GtkBuilder *gxml;
-#ifdef HAVE_GTK_314
+#if GTK_CHECK_VERSION(3, 14, 0)
 	glade_file =
 	    gui_general_user_file("xi-menus-popup.gtkbuilder", FALSE);
 #else
@@ -1076,7 +1079,7 @@ static GtkWidget *create_menu_modules(void)
 	gchar *glade_file;
 #ifdef USE_GTKBUILDER
 	GtkBuilder *gxml;
-#ifdef HAVE_GTK_314
+#if GTK_CHECK_VERSION(3, 14, 0)
 	glade_file =
 	    gui_general_user_file("xi-menus-popup.gtkbuilder", FALSE);
 #else
@@ -1143,13 +1146,19 @@ on_outlined_topic_activate(GtkMenuItem *menuitem, gpointer user_data)
 	main_prayerlist_outlined_topic_create();
 }
 
+G_MODULE_EXPORT void
+on_book_chapter_activate(GtkMenuItem *menuitem, gpointer user_data)
+{
+	main_prayerlist_book_chapter_create();
+}
+
 GtkWidget *create_menu_prayerlist(void)
 {
 	GtkWidget *menu;
 	gchar *glade_file;
 #ifdef USE_GTKBUILDER
 	GtkBuilder *gxml;
-#ifdef HAVE_GTK_314
+#if GTK_CHECK_VERSION(3, 14, 0)
 	glade_file =
 	    gui_general_user_file("xi-menus-popup.gtkbuilder", FALSE);
 #else
@@ -1195,7 +1204,7 @@ GtkWidget *create_menu_prayerlist_mod(void)
 	gchar *glade_file;
 #ifdef USE_GTKBUILDER
 	GtkBuilder *gxml;
-#ifdef HAVE_GTK_314
+#if GTK_CHECK_VERSION(3, 14, 0)
 	glade_file =
 	    gui_general_user_file("xi-menus-popup.gtkbuilder", FALSE);
 #else
@@ -1341,7 +1350,7 @@ static void create_search_results_page(GtkWidget *notebook)
 	gtk_widget_show(sidebar.results_list);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow3),
 			  sidebar.results_list);
-#ifndef HAVE_GTK_310
+#if !GTK_CHECK_VERSION(3, 10, 0)
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(sidebar.results_list),
 				     TRUE);
 #endif
@@ -1442,7 +1451,9 @@ GtkWidget *gui_create_sidebar(GtkWidget *paned)
 	GtkWidget *scrolledwindow4;
 	GtkWidget *scrolledwindow_bm;
 	GtkWidget *title_label = NULL;
+#ifndef USE_WEBKIT2
 	GtkWidget *scrolledwindow;
+#endif
 
 	GtkWidget *table2;
 
@@ -1465,6 +1476,7 @@ GtkWidget *gui_create_sidebar(GtkWidget *paned)
 			 (gchar *)"paned_sidebar");
 	widgets.shortcutbar = widgets.paned_sidebar;
 
+#ifndef USE_WEBKIT2
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
 	gtk_box_pack_start(GTK_BOX(widgets.box_side_preview),
@@ -1475,18 +1487,23 @@ GtkWidget *gui_create_sidebar(GtkWidget *paned)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolledwindow,
 					    settings.shadow_type);
+#endif
 
 	sidebar.html_viewer_widget =
 	    GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, SB_VIEWER_TYPE));
+	gtk_widget_show(sidebar.html_viewer_widget);
+#ifdef USE_WEBKIT2
+	gtk_box_pack_start(GTK_BOX(widgets.box_side_preview), sidebar.html_viewer_widget, TRUE, TRUE, 0);
+#else
 	gtk_container_add(GTK_CONTAINER(scrolledwindow),
 			  sidebar.html_viewer_widget);
-	gtk_widget_show(sidebar.html_viewer_widget);
+#endif
 
 /* ---------------------------------------------------------------- */
 /* 2x2 button box set: modules/bookmarks/search/vlist */
 /* ---------------------------------------------------------------- */
 
-#ifdef HAVE_GTK_34
+#if GTK_CHECK_VERSION(3, 4, 0)
 	table2 = gtk_grid_new();
 	gtk_widget_show(table2);
 	gtk_box_pack_start(GTK_BOX(vbox1), table2, FALSE, TRUE, 0);
@@ -1502,26 +1519,42 @@ GtkWidget *gui_create_sidebar(GtkWidget *paned)
 	gtk_grid_attach(GTK_GRID(table2), button_bookmarks, 1, 0, 1, 1);
 	gtk_button_set_relief(GTK_BUTTON(button_bookmarks),
 			      GTK_RELIEF_HALF);
+#if GTK_CHECK_VERSION(3, 20, 0)
+	gtk_widget_set_focus_on_click(GTK_WIDGET(button_bookmarks), FALSE);
+#else
 	gtk_button_set_focus_on_click(GTK_BUTTON(button_bookmarks), FALSE);
+#endif
 
 	button_search = gtk_toggle_button_new_with_mnemonic(_("Search"));
 	gtk_widget_show(button_search);
 	gtk_grid_attach(GTK_GRID(table2), button_search, 0, 1, 1, 1);
 	gtk_button_set_relief(GTK_BUTTON(button_search), GTK_RELIEF_HALF);
+#if GTK_CHECK_VERSION(3, 20, 0)
+	gtk_widget_set_focus_on_click(GTK_WIDGET(button_search), FALSE);
+#else
 	gtk_button_set_focus_on_click(GTK_BUTTON(button_search), FALSE);
+#endif
 
 	button_v_lists =
 	    gtk_toggle_button_new_with_mnemonic(_("Verse List"));
 	gtk_widget_show(button_v_lists);
 	gtk_grid_attach(GTK_GRID(table2), button_v_lists, 1, 1, 1, 1);
 	gtk_button_set_relief(GTK_BUTTON(button_v_lists), GTK_RELIEF_HALF);
+#if GTK_CHECK_VERSION(3, 20, 0)
+	gtk_widget_set_focus_on_click(GTK_WIDGET(button_v_lists), FALSE);
+#else
 	gtk_button_set_focus_on_click(GTK_BUTTON(button_v_lists), FALSE);
+#endif
 
 	button_modules = gtk_toggle_button_new_with_mnemonic(_("Modules"));
 	gtk_widget_show(button_modules);
 	gtk_grid_attach(GTK_GRID(table2), button_modules, 0, 0, 1, 1);
 	gtk_button_set_relief(GTK_BUTTON(button_modules), GTK_RELIEF_HALF);
+#if GTK_CHECK_VERSION(3, 20, 0)
+	gtk_widget_set_focus_on_click(GTK_WIDGET(button_modules), FALSE);
+#else
 	gtk_button_set_focus_on_click(GTK_BUTTON(button_modules), FALSE);
+#endif
 
 #else
 
