@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * tabbed_browser.c - functions to facilitate tabbed browsing of different passages at once
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -857,19 +857,17 @@ static GtkWidget *tab_widget_new(PASSAGE_TAB_INFO *tbinf,
 #endif
 
 	g_return_val_if_fail(label_text != NULL, NULL);
-#ifdef HAVE_GTK_310
-	tbinf->button_close =
-	    gtk_button_new_from_icon_name("window-close-symbolic",
-					  GTK_ICON_SIZE_MENU);
+#if GTK_CHECK_VERSION(3, 10, 0)
+	tbinf->button_close = gtk_button_new_from_icon_name("window-close-symbolic", GTK_ICON_SIZE_MENU);
+#if GTK_CHECK_VERSION(3, 20, 0)
+	gtk_button_set_relief(GTK_BUTTON(tbinf->button_close), GTK_RELIEF_NONE);
 #else
-	GtkWidget *tmp_toolbar_icon =
-		gtk_image_new_from_stock(GTK_STOCK_CLOSE,
-					 GTK_ICON_SIZE_MENU);
+#endif
+#else
+	GtkWidget *tmp_toolbar_icon = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
 	tbinf->button_close = gtk_button_new();
-	gtk_button_set_image(GTK_BUTTON(tbinf->button_close),
-			     tmp_toolbar_icon);
-	gtk_button_set_relief(GTK_BUTTON(tbinf->button_close),
-			      GTK_RELIEF_NONE);
+	gtk_button_set_image(GTK_BUTTON(tbinf->button_close), tmp_toolbar_icon);
+	gtk_button_set_relief(GTK_BUTTON(tbinf->button_close), GTK_RELIEF_NONE);
 #endif
 
 #ifndef USE_GTK_3
