@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * utilities.c - support functions
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1094,14 +1094,19 @@ static void language_add(const char *language, int module_type)
 	++(language_set[module_type].count);
 }
 
-/* comparator function pulled verbatim from qsort(3). */
+/* comparator function pulled verbatim from qsort(3) */
+/* but with function changed to ucol_strcollUTF8(3). */
+/* http://icu-project.org/apiref/icu4c/ucol_8h.html  */
 static int cmpstringp(const void *p1, const void *p2)
 {
 	/* The actual arguments to this function are "pointers to
 	   pointers to char", but strcmp(3) arguments are "pointers
 	   to char", hence the following cast plus dereference */
 
-	return strcmp(*(char *const *)p1, *(char *const *)p2);
+	return ucol_strcollUTF8(collator,
+				*(char *const *)p1, -1,
+				*(char *const *)p2, -1,
+				&collator_status);
 }
 
 /* retrieve the language set specific to the module type requested */
@@ -1173,6 +1178,18 @@ language_make_list(GList *modlist,
 		modlist = g_list_next(modlist);
 	}
 
+	/* self-defense, prior to qsort(3). */
+	/* if this is 1st run, then we have not yet init'd the sword engine,
+	 * in turn we do not have sword_locale or collator. we need collator
+	 * in order to use qsort(3). it's a gross, unreliable hack, but we
+	 * will simply use $LANG in this one instance, un-massaged by the
+	 * more correct set_sword_locale().
+	 */
+	if (!collator) {
+		char *locale = getenv("LANG");
+		collator = ucol_open((locale ? locale : ""), &collator_status);
+	}
+
 	/* sort */
 	for (i = 0; i < N_LANGSET_MODTYPES; ++i) {
 		qsort(language_set[i].ptr,
@@ -1666,7 +1683,7 @@ void ReadAloud(unsigned int verse, const char *suppliedtext)
 			return;
 
 		GString *text = g_string_new(NULL);
-		if (verse != 0)
+		if ((settings.showversenum) && (verse != 0))
 			g_string_printf(text, "%d. ...  %s", verse,
 					suppliedtext);
 		// use of ". ..." is to induce proper pauses.
