@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * biblesync_glue.cc
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,12 +101,18 @@ biblesync_navigate(char cmd, string speaker_uuid,
 	// mismatch
 	case 'M':
 		if (settings.bs_mismatch) {
-			message = BSP + (string)_("Mismatched packet\n\n") + info + ((info.substr(0, 8) == "announce")
-											 ? ("\nMessage: " + presence)
-											 : ("\nBible: " + bible + "; Ref: " + ref + "; Alt: " + alt + "\nGroup: " + group + "; Domain: " + domain)) +
-				  (settings.bs_debug
-				       ? ("\n\n" + (string)dump)
-				       : "");
+			message = BSP + (string)_("Mismatched packet\n\n")
+				+ info
+				+ ((info.substr(0, 8) == "announce")
+				   ? ("\nMessage: " + presence)
+				   : ("\nBible: " + bible
+				      + "; Ref: " + ref
+				      + "; Alt: " + alt
+				      + "\nGroup: " + group
+				      + "; Domain: " + domain))
+				+ (settings.bs_debug
+				   ? ("\n\n" + (string)dump)
+				   : "");
 			gui_generic_warning((char *)message.c_str());
 		}
 		break;
@@ -252,7 +258,17 @@ biblesync_navigate(char cmd, string speaker_uuid,
 		break;
 
 	default:
-		message = _("ERROR: unknown BibleSync indicator: ") + cmd + (string) ".\n" + (string)_("Other indications are:") + "\nbible: " + bible + "\nref: " + ref + "\nalt: " + alt + "\ngroup: " + group + "\ndomain: " + domain + "\ninfo: " + info + "\ndump:\n" + dump;
+		message = _("ERROR: unknown BibleSync indicator: ")
+			+ cmd
+			+ (string) ".\n"
+			+ (string)_("Other indications are:")
+			+ "\nbible: " + bible
+			+ "\nref: " + ref
+			+ "\nalt: " + alt
+			+ "\ngroup: " + group
+			+ "\ndomain: " + domain
+			+ "\ninfo: " + info
+			+ "\ndump:\n" + dump;
 		gui_generic_warning((char *)message.c_str());
 		break;
 	}
@@ -500,7 +516,7 @@ void biblesync_update_speaker()
 	    gtk_tree_view_new_with_model(GTK_TREE_MODEL(model_speakers));
 	gtk_widget_show(speaker_list);
 	gtk_container_add(GTK_CONTAINER(speaker_window), speaker_list);
-#ifndef HAVE_GTK_310
+#if !GTK_CHECK_VERSION(3, 10, 0)
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(speaker_list), TRUE);
 #endif
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(speaker_list), TRUE);
@@ -519,7 +535,7 @@ void biblesync_update_speaker()
 
 	column = gtk_tree_view_column_new();
 	image =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_image_new_from_icon_name("emblem-ok-symbolic", GTK_ICON_SIZE_MENU);
 #else
 	    gtk_image_new_from_stock(GTK_STOCK_APPLY, GTK_ICON_SIZE_MENU);
@@ -552,7 +568,7 @@ void biblesync_update_speaker()
 	column = gtk_tree_view_column_new_with_attributes(_("D/I"), renderer,
 							  "text", COLUMN_DIRECT, NULL);
 	image =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_image_new_from_icon_name("emblem-default", GTK_ICON_SIZE_MENU);
 #else
 	    gtk_image_new_from_stock("gtk-yes", GTK_ICON_SIZE_MENU); // XXX
@@ -768,7 +784,10 @@ int biblesync_active_xmit_allowed()
  */
 const char *biblesync_get_passphrase()
 {
-	return biblesync->getPassphrase().c_str();
+	static string phrase;
+
+	phrase = biblesync->getPassphrase();
+	return phrase.c_str();
 }
 
 /******************************************************************************
