@@ -3,7 +3,7 @@
  * mod_global_ops.c - setup for SWORD global options and
  *                    a few of our own in the gui
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -208,8 +208,6 @@ GLOBAL_OPS *main_new_globals(const gchar *mod_name)
 	    gui_of2tf(module_options[mod_name]["Transliterated Forms"].c_str());
 	ops->enumerated =
 	    gui_of2tf(module_options[mod_name]["Enumerations"].c_str());
-	ops->glosses =
-	    gui_of2tf(module_options[mod_name]["Glosses"].c_str());
 	ops->morphseg =
 	    gui_of2tf(module_options[mod_name]["Morpheme Segmentation"].c_str());
 
@@ -245,6 +243,10 @@ GLOBAL_OPS *main_new_globals(const gchar *mod_name)
 	ops->hebrewcant =
 	    (module_options[mod_name]["Hebrew Cantillation"] != "Off");
 
+	// more special case default on: japanese glosses.
+	ops->glosses =
+	    (module_options[mod_name]["Glosses"] != "Off");
+
 	// we prefer and assume paragraph layout.
 	// we take user preference, and alter our default for
 	// those modules showing proper configuration for it.
