@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * module_dialog.h - view module in a dialog
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -125,7 +125,8 @@ void main_dialog_goto_bookmark(const gchar *module,
 gint main_dialogs_url_handler(DIALOG_DATA *t, const gchar *url,
 			      gboolean clicked);
 DIALOG_DATA *main_dialogs_open(const gchar *mod_name,
-			       const gchar *key);
+			       const gchar *key,
+			       const gboolean maximize);
 
 #ifdef __cplusplus
 }
