@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_dialog.cc - glue  (: very sticky :)
  *
- * Copyright (C) 2004-2015 Xiphos Developer Team
+ * Copyright (C) 2004-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -406,7 +406,7 @@ void main_delete_range(void)
 			      name_string);
 
 	if (gui_yes_no_dialog(str, (char *)
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 			      "dialog-warning"
 #else
 			      GTK_STOCK_DIALOG_WARNING
@@ -659,7 +659,7 @@ void main_delete_module(GtkTreeView *treeview)
 			      _("Are you sure you want to remove the selected module?"));
 
 	if (gui_yes_no_dialog(str, (char *)
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 			      "dialog-warning"
 #else
 			      GTK_STOCK_DIALOG_WARNING
