@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * settings.h - structure definitions
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -208,6 +208,9 @@ struct _settings
 	/* statusbar setting */
 	int statusbar;
 
+	/* parallel color alternation */
+	int alternation;
+
 	/* if true parallel tab is showing */
 	int paratab_showing;
 
