@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sidebar.cc - sidebar interface to sword
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -344,9 +344,8 @@ void main_create_pixbufs(void)
 		    pixbuf_finder("book_open_rtol.png", 16, NULL);
 	}
 
-#ifdef USE_GTK_3
-
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 0, 0)
+#if GTK_CHECK_VERSION(3, 10, 0)
 	GtkIconTheme *icon_theme = gtk_icon_theme_get_default();
 	pixbufs->pixbuf_helpdoc =
 	    gtk_icon_theme_load_icon(icon_theme,
