@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword.cc - glue
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -88,6 +88,10 @@ using namespace sword;
 char *sword_locale = NULL;
 gboolean companion_activity = FALSE;
 
+/* Unicode collation necessities. */
+UCollator* collator;
+UErrorCode collator_status;
+
 extern gboolean valid_scripture_key;
 
 // these track together.  when one changes, so does the other.
@@ -787,6 +791,7 @@ void main_init_backend(void)
 	if (!lang)
 		lang = "C";
 	sword_locale = set_sword_locale(lang);
+	collator = ucol_open(sword_locale, &collator_status);
 	lang = LocaleMgr::getSystemLocaleMgr()->getDefaultLocaleName();
 
 	backend = new BackEnd();
@@ -1122,7 +1127,7 @@ void main_display_commentary(const char *mod_name,
 			if (gui_yes_no_dialog(companion_question, NULL)) {
 				main_display_bible(name_set[0], key);
 				for (int i = 1; i < name_length; i++) {
-					main_dialogs_open(name_set[i], key);
+					main_dialogs_open(name_set[i], key, FALSE);
 				}
 			}
 			g_free(companion_question);
@@ -1291,7 +1296,7 @@ void main_display_bible(const char *mod_name,
 			if (gui_yes_no_dialog(companion_question, NULL)) {
 				main_display_commentary(name_set[0], key);
 				for (int i = 1; i < name_length; i++) {
-					main_dialogs_open(name_set[i], key);
+					main_dialogs_open(name_set[i], key, FALSE);
 				}
 			}
 			g_free(companion_question);
