@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * url.cc - support functions
  *
- * Copyright (C) 2004-2015 Xiphos Developer Team
+ * Copyright (C) 2004-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ static void alert_url_not_found(const gchar *url)
 
 	dialog = gui_new_dialog();
 	dialog->stock_icon =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    (gchar *)"dialog-information";
 #else
 	    (gchar *)GTK_STOCK_DIALOG_INFO;
